```{python initialize=true}
import matplotlib
from matplotlib import pyplot

import numpy as np

from common import draw_classic_axes, configure_plotting

configure_plotting()

pi = np.pi
```

# Solutions for lecture 7 exercises

## Exercise 1: Lattice vibrations

### Subquestion 1

Hint: Normal modes have the same function as $\mathbf{e}_1,\mathbf{e}_2,\mathbf{e}_3$ have in $\mathbb{R}^3$. That is, for every vector $\mathbf{v}$ we have $\mathbf{v} = a\mathbf{e}_1 + b\mathbf{e}_2 + c\mathbf{e}_3$.

Hint: The lecture concerns atom vibrations, so what will a phonon be?

??? hint "Major hint"

    What's the question's title?

Hint: What kind of particles obey Bose-Einstein statistics? What kind of 'particles' are phonons?

### Subquestion 2

Group velocity is given as $v=\hbar^{-1}\frac{\partial E}{\partial k}$ with $E=\hbar\omega$ and $g(\omega) = \frac{dN}{d\omega} = \frac{dN}{dk}\frac{dk}{d\omega}$. So we find: $$ v(k) = \frac{a}{2}\sqrt{\frac{2\kappa}{m}}\frac{\sin(ka)}{\sqrt{1-\cos(ka)}}$$ $$ g(\omega) = \frac{L}{2\pi}\frac{d}{d\omega} \bigg [\frac{2}{a}\sin^{-1}\bigg(\sqrt{\frac{m}{\kappa}}\frac{\omega}{2} \bigg) \bigg ] \\ = \frac{L}{\pi a} \frac{1}{\sqrt{\frac{4\kappa}{m}-\omega^2}}$$

### Subquestion 3

```python
pyplot.subplot(1,2,1)
k = np.linspace(-pi+0.01, pi-0.01, 300)
pyplot.plot(k[0:149], np.sin(k[0:149])/(np.sqrt(1-np.cos(k[0:149]))),'b');
pyplot.plot(k[150:300], np.sin(k[150:300])/(np.sqrt(1-np.cos(k[150:300]))),'b');
pyplot.xlabel('$k$'); pyplot.ylabel('$v(k)$');
pyplot.xticks([-pi, 0, pi], [r'$-\pi/2$', 0, r'$\pi/2$']);
pyplot.yticks([-np.sqrt(2), 0, np.sqrt(2)], [r'$-2\sqrt{\frac{\kappa}{m}}$', 0, r'$2\sqrt{\frac{\kappa}{m}}$']);
pyplot.tight_layout();

pyplot.subplot(1,2,2)
w = np.linspace(-0.95, 0.95, 300);
g = 1/np.sqrt(1-w**2);
pyplot.plot(w, g, 'b');
pyplot.xlabel(r'$\omega$'); pyplot.ylabel('$g(w)$');
pyplot.xticks([-1, 0, 1], [r'$-2\sqrt{\frac{k}{m}}$', 0, r'$2\sqrt{\frac{k}{m}}$']);
pyplot.yticks([0.5, 1], [0, r'$\frac{L}{2\pi a}\sqrt{\frac{\kappa}{m}}$']);
pyplot.tight_layout();
```

### Subquestion 4

Hint: The group velocity is given as $v = \frac{d\omega}{dk}$, draw a coordinate system **under** or **above** the dispersion graph with $k$ on the x-axis in which you draw $\frac{d\omega}{dk}$. Draw a coordinate system **next** to the dispersion with *$g(\omega)$ on the y-axis* in which you graph $\big(\frac{d\omega}{dk}\big)^{-1} \approx \frac{1}{\frac{d\omega}{dk}}$ (This is **definitely** not an equality sign, but you can use this 'approximation' to graph the density of states).

??? hint "Plots"

    ![](figures/dispersion_groupv_dos.svg)

## Exercise 2: Vibrational heat capacity of a 1D monatomic chain

### Subquestion 1

For the energy we have: $$U = \int \hbar \omega g(\omega) (n(\omega,T) + \frac{1}{2})d\omega$$ with $g(\omega)$ as in Exercise 1 subquestion 2 and $n(\omega,T) = \frac{1}{e^{\hbar\omega/k_BT}-1}$.

### Subquestion 2


For the heat capacity we have: $$C = \frac{\partial U}{\partial T} = \int \hbar\omega g(\omega) \frac{\partial n(\omega,T)}{\partial T}d\omega$$



